summaryrefslogtreecommitdiffstats
path: root/kicker/libkicker/panelbutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/libkicker/panelbutton.h')
-rw-r--r--kicker/libkicker/panelbutton.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kicker/libkicker/panelbutton.h b/kicker/libkicker/panelbutton.h
index 3a455a58f..b67bc2b9a 100644
--- a/kicker/libkicker/panelbutton.h
+++ b/kicker/libkicker/panelbutton.h
@@ -35,7 +35,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include "kickertip.h"
class TQPopupMenu;
-class KConfigGroup;
+class TDEConfigGroup;
class KShadowEngine;
/**
@@ -66,9 +66,9 @@ public:
/**
* Prompts the button to save it's configuration. Subclass specific
* settings should be saved in this method to the KConfigGroup passed in.
*/
- virtual void saveConfig(KConfigGroup&) const {}
+ virtual void saveConfig(TDEConfigGroup&) const {}
/**
* Reimplement this to display a properties dialog for your button.
@@ -66,9 +66,9 @@ public:
/**
* Prompts the button to save it's configuration. Subclass specific
- * settings should be saved in this method to the KConfigGroup passed in.
+ * settings should be saved in this method to the TDEConfigGroup passed in.
*/